@@ -20,7 +20,7 @@ from .containers import (
     SplitterContainer,
     StackedContainer,
     TabbedContainer,
-    ToolBox
+    ToolBoxContainer
     )
 from ._base import BaseGui, PopUpMode, ErrorMode
 
@@ -196,6 +196,7 @@ def make_gui(container: type[ContainerWidget], no_margin: bool = True):
             self._menubar = None
             
             self.native.setObjectName(self.name)
+            self.native.setWindowTitle(self.name)
         
         def insert(self: cls, key: int, widget: Widget):
             _hide_labels = (_LabeledWidget, ButtonWidget, ClassGuiBase, FrozenContainer, Label,
@@ -284,7 +285,7 @@ class CollapsibleClassGui: pass
 @make_gui(ButtonContainer)
 class ButtonClassGui: pass
 
-@make_gui(ToolBox, no_margin=False)
+@make_gui(ToolBoxContainer, no_margin=False)
 class ToolBoxClassGui: pass
 
 @make_gui(TabbedContainer, no_margin=False)
