@@ -5,7 +5,6 @@ from functools import wraps
 from typing import Callable, Any, TYPE_CHECKING
 from docstring_parser import parse
 from qtpy.QtWidgets import QApplication, QMessageBox
-from magicgui.widgets._bases import ValueWidget
 
 if TYPE_CHECKING:
     from magicgui.widgets._bases import Widget
@@ -159,3 +158,9 @@ def get_app():
     global APPLICATION
     APPLICATION = app
     return app
+
+def screen_center():
+    """
+    Get the center coordinate of the screen.
+    """    
+    return QApplication.desktop().screen().rect().center()
\ No newline at end of file
